@@ -6,7 +6,9 @@ task <- function(y) {
   boot(nuke.data, nuke.fun, R=y, m=1, fit.pred=new.fit, x.pred=new.data)
 }
 
-library(nws); s <- sleigh()
+if (! suppressWarnings(require(nwsPro, quietly=TRUE)))
+  library(nws)
+s <- sleigh()
 
 R <- 20000
 chunkSize <- ceiling(R / workerCount(s))  # rounding up
